@@ -38,6 +38,8 @@ urlpatterns = [
     path('avenant_mkPDF', views_download.avenant_mkPDF, name='avenant_mkPDF'),
     path('correspondance_nom', ajaxviews.correspondance_nom,
          name='correspondance_nom'),
+    path('correspondance_nom_caution', ajaxviews.correspondance_nom_caution,
+         name='correspondance_nom_caution'),
     path('correspondance_classe', ajaxviews.correspondance_classe,
          name='correspondance_classe'),
     path('correspondance_livre', ajaxviews.correspondance_livre,
@@ -246,4 +248,13 @@ urlpatterns = [
          name='makeImmobile_msg'),
     path('commente_caution_msg', ajaxviews.commente_caution_msg,
          name='commente_caution_msg'),
+    path('que_prendre', ajaxviews.que_prendre, name='que_prendre'),
+    path('livres_de_classe', ajaxviews.livres_de_classe,
+         name='livres_de_classe'),
+    path('livre_retrouve_go', ajaxviews.livre_retrouve_go,
+         name='livre_retrouve_go'),
+    path('choix_eleves', views.choix_eleves, name='choix_eleves'),
+    path('action_courrier', views.action_courrier, name='action_courrier'),
+    path('action_courrier_go', ajaxviews.action_courrier_go,
+         name='action_courrier_go'),
 ]
