@@ -974,13 +974,25 @@ def invite_inscription_provisoire(request):
     fin_validite = d + timedelta(minutes=30)
     dernier_autorise = d - timedelta(minutes=30)
     # on annule les champs autorisation_provisoire_inscription des élèves
-    # qui ont dépassé la fin de validité
+    # qui ont dépassé la fin de validité, à moins qu'ils aient déjà
+    # des livres prêtés
     # on efface d'abord les élèves qu'on n'a pas vérifiés dans les 30 minutes
     eleves_perimes = Eleves.objects.filter(
         a_verifier=True,
         autorisation_provisoire_inscription__lt=dernier_autorise)
     for e in eleves_perimes:
-        e.delete()
+        if not(Prets.objects.filter(eleve = e)):
+            # il n'y a pas de livres prêtés pour l'élève e, on l'efface
+            # ainsi que sa caution automatique
+            c = Cautions.objects.get(numero = e.no_caution)
+            c.delete()
+            e.delete()
+        else:
+            # au moins un livre a été prêté, l'élève est considéré comme
+            # vérifié
+            e.a_verifier=False
+            e.autorisation_provisoire_inscription = None
+            e.save()
     eleves_ok = Eleves.objects.filter(
         a_verifier=False,
         autorisation_provisoire_inscription__lt=dernier_autorise)
